# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .authorization_context import AuthorizationContext

__all__ = ["AuthorizationResponse"]


class AuthorizationResponse(BaseModel):
    id: Optional[str] = None

    context: Optional[AuthorizationContext] = None

    provider_id: Optional[str] = None

    scopes: Optional[List[str]] = None

    status: Optional[Literal["not_started", "pending", "completed", "failed"]] = None

    url: Optional[str] = None

    user_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["WorkerCreateParams", "HTTP", "Mcp"]


class WorkerCreateParams(TypedDict, total=False):
    id: Required[str]

    enabled: bool

    http: HTTP

    mcp: Mcp

    type: str


class HTTP(TypedDict, total=False):
    retry: Required[int]

    secret: Required[str]

    timeout: Required[int]

    uri: Required[str]


class Mcp(TypedDict, total=False):
    retry: Required[int]

    timeout: Required[int]

    uri: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from ..._models import BaseModel

__all__ = ["AuthorizationContext"]


class AuthorizationContext(BaseModel):
    token: Optional[str] = None

    user_info: Optional[Dict[str, object]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, TypedDict

__all__ = ["ToolGetParams"]


class ToolGetParams(TypedDict, total=False):
    include_format: List[Literal["arcade", "openai", "anthropic"]]
    """Comma separated tool formats that will be included in the response."""

    user_id: str
    """User ID"""
